@@ -91,5 +91,13 @@ if (testLevel>1) {
         expect_true(all(summary(ff)$which.OK))
     })
 
+    test_that("maxfun works", {
+        gm_it10 <- suppressWarnings(allFit(fit_cbpp_1, verbose=FALSE, maxfun = 10))
+        v <- vapply(gm_it10, function(x) as.integer(x@optinfo$feval), FUN.VALUE=1L)
+        ## function values are sometimes off a bit (due to initialization or Hessian calculation)
+        ##  but close enough ...
+        expect_true(all(v %in% c(10, 11, NA, 18)))
+    })
+
 
 }  ## testLevel
